@@ -7,11 +7,10 @@ This is also the fallback implementation to use when no known CI platform is det
 import argparse
 import re
 import subprocess
+from functools import cached_property
 from pathlib import Path
 from typing import Optional
 
-from backports.cached_property import cached_property
-
 from phylum.ci.ci_base import CIBase
 from phylum.ci.git import git_curent_branch_name, git_remote
 
