@@ -79,8 +79,7 @@ def get_phylum_analysis(ci_env: CIBase) -> dict:
     cmd.extend(["--verbose", "--json"])
     cmd.extend(str(lockfile.path) for lockfile in ci_env.lockfiles)
 
-    shell_escaped_cmd = " ".join(shlex.quote(arg) for arg in cmd)
-    print(f" [*] Performing analysis with command: {shell_escaped_cmd}")
+    print(f" [*] Performing analysis with command: {shlex.join(cmd)}")
     try:
         analysis_result = subprocess.run(cmd, check=True, capture_output=True, text=True).stdout
     except subprocess.CalledProcessError as err:
@@ -253,7 +252,7 @@ def main(args: Optional[Sequence[str]] = None) -> int:
         parsed_args.version = version_check(parsed_args.version)
     else:
         print(" [+] Phylum CLI version not specified")
-        parsed_args.version = default_phylum_cli_version()
+        parsed_args.version = version_check(default_phylum_cli_version())
     print(f" [*] Using Phylum CLI version: {parsed_args.version}")
 
     # Detect which CI environment, if any, we are in
